var plplot_8d =
[
    [ "PLcGrid", "structplplot_1_1PLcGrid.html", "structplplot_1_1PLcGrid" ],
    [ "PLcGrid2", "structplplot_1_1PLcGrid2.html", "structplplot_1_1PLcGrid2" ],
    [ "_N1", "structplplot_1_1__N1.html", "structplplot_1_1__N1" ],
    [ "_N2", "structplplot_1_1__N2.html", "structplplot_1_1__N2" ],
    [ "_N3", "structplplot_1_1__N3.html", "structplplot_1_1__N3" ],
    [ "_N4", "structplplot_1_1__N4.html", "structplplot_1_1__N4" ],
    [ "_N5", "structplplot_1_1__N5.html", "structplplot_1_1__N5" ],
    [ "_N6", "structplplot_1_1__N6.html", "structplplot_1_1__N6" ],
    [ "_N7", "structplplot_1_1__N7.html", "structplplot_1_1__N7" ],
    [ "_N8", "structplplot_1_1__N8.html", "structplplot_1_1__N8" ],
    [ "_N9", "structplplot_1_1__N9.html", "structplplot_1_1__N9" ],
    [ "_N10", "structplplot_1_1__N10.html", "structplplot_1_1__N10" ],
    [ "_N11", "structplplot_1_1__N11.html", "structplplot_1_1__N11" ],
    [ "c_pl_setcontlabelformat", "plplot_8d.html#aee71f42f3dd91fbd4c3023d5cbbb76c9", null ],
    [ "c_pl_setcontlabelparam", "plplot_8d.html#adae9a44f32a118485bd1e3c93672991b", null ],
    [ "c_pladv", "plplot_8d.html#ac80a8680ccea0eb4bca9610e51e2890d", null ],
    [ "c_plarc", "plplot_8d.html#a087e8e9e88f4dfeda75e247d8427c078", null ],
    [ "c_plaxes", "plplot_8d.html#a5a2294470fad82d8d1903ef7ab2f039b", null ],
    [ "c_plbin", "plplot_8d.html#a1cffa6aacb8418d7d04264d0efe3ac9a", null ],
    [ "c_plbop", "plplot_8d.html#a24ef1d23f50b90b5e2c7713ff23011bd", null ],
    [ "c_plbox", "plplot_8d.html#ac8b56eeae94e3a31bce84319403f5c05", null ],
    [ "c_plbox3", "plplot_8d.html#af6474cc7276a3eeb18daac8b85a9dce7", null ],
    [ "c_plbtime", "plplot_8d.html#a3645feff751dc481df03309fe050608d", null ],
    [ "c_plcalc_world", "plplot_8d.html#a633ae2dc8fb0945218d5649ac97c57c7", null ],
    [ "c_plclear", "plplot_8d.html#a6920227b7c3151c32e23a019a38e6e4a", null ],
    [ "c_plcol0", "plplot_8d.html#a3e28fda9a95dc8b2fa32d83fcc87d171", null ],
    [ "c_plcol1", "plplot_8d.html#a3623f4f7d266155f40cacc03ee9c7942", null ],
    [ "c_plcolorbar", "plplot_8d.html#a4964a6240e828bb7b8eaa1f1ec7805c3", null ],
    [ "c_plconfigtime", "plplot_8d.html#affd4a9742097665110b2cdc8732207f0", null ],
    [ "c_plcont", "plplot_8d.html#ae4f6b3c11f651d6103168853fdf8eec1", null ],
    [ "c_plcpstrm", "plplot_8d.html#a695e1e6c1def7151027bb5478dc74649", null ],
    [ "c_plctime", "plplot_8d.html#a8ea62d1294f79d32b7b7d8a31a4a602b", null ],
    [ "c_plend", "plplot_8d.html#abc2df3677e61a8fad26cedd5b51a2048", null ],
    [ "c_plend1", "plplot_8d.html#acf191144197c70cba08a5ba074ee2b01", null ],
    [ "c_plenv", "plplot_8d.html#aa5a49c269c021e95fc9fcb931bce884a", null ],
    [ "c_plenv0", "plplot_8d.html#a0dec50f8df8650e5c63240732c5c139f", null ],
    [ "c_pleop", "plplot_8d.html#a775da376e7d176f78612b9f7fd1cc83a", null ],
    [ "c_plerrx", "plplot_8d.html#ac076ac0b43273f5b03bb1dfd119520c6", null ],
    [ "c_plerry", "plplot_8d.html#ad07526bf32f693dd555bb130fea6cb08", null ],
    [ "c_plfamadv", "plplot_8d.html#a16d0387c29f7b55f2f715eda38ddef08", null ],
    [ "c_plfill", "plplot_8d.html#a29dcedcfe602ab89eb6c7c39bd3a13d4", null ],
    [ "c_plfill3", "plplot_8d.html#a9922ad7f71ded2e05ecac737560553c9", null ],
    [ "c_plflush", "plplot_8d.html#a40447516f265e81a351fea707c9d2014", null ],
    [ "c_plfont", "plplot_8d.html#a4c8504acd90d57225605b3100b9ae6a2", null ],
    [ "c_plfontld", "plplot_8d.html#a36abac35d8a123b9355536166cd4d2be", null ],
    [ "c_plgchr", "plplot_8d.html#ace3a0eb9e18aab432711eb51ed647f8d", null ],
    [ "c_plgcmap1_range", "plplot_8d.html#aec44f4ef3d50f1dc278adae11964326b", null ],
    [ "c_plgcol0", "plplot_8d.html#acdf17d7691d47a3d8a68d433bd5d80fd", null ],
    [ "c_plgcol0a", "plplot_8d.html#a99ecf15dce209e6c20809005ae6347ff", null ],
    [ "c_plgcolbg", "plplot_8d.html#af579d375a633a82a1640520f80bbefc5", null ],
    [ "c_plgcolbga", "plplot_8d.html#a13b9989b5d67feed9f7ee409e3caf95c", null ],
    [ "c_plgcompression", "plplot_8d.html#a958408ea497528c844fcd342d2a6e62a", null ],
    [ "c_plgdev", "plplot_8d.html#ab4f16c8d829f988f7224946f97f1a503", null ],
    [ "c_plgdidev", "plplot_8d.html#a08b05da624e55989128a0b5a6c030158", null ],
    [ "c_plgdiori", "plplot_8d.html#a1c89b39dbbfc1e0ff0a1d69ab32ed18a", null ],
    [ "c_plgdiplt", "plplot_8d.html#aa3aed6fec8adb654a82ed2f76e5b62c0", null ],
    [ "c_plgfam", "plplot_8d.html#aeaa6cb5cf62b5554b27ed0a558cc1419", null ],
    [ "c_plgfci", "plplot_8d.html#a940be8f28afc4213372e7028a49332dc", null ],
    [ "c_plgfnam", "plplot_8d.html#a7abcf0815dc45adef4c8e9f6976457bb", null ],
    [ "c_plgfont", "plplot_8d.html#a09d7ed095b889b350dfeea51e0643164", null ],
    [ "c_plglevel", "plplot_8d.html#a03f6f84ce00bddaf3a62753f102bbaee", null ],
    [ "c_plgpage", "plplot_8d.html#aead581d0f4d1ba49fea7f68cf637125c", null ],
    [ "c_plgra", "plplot_8d.html#aba346d858ce4b8034c151817a6660250", null ],
    [ "c_plgradient", "plplot_8d.html#aafb18966be3797e86f37fedbaf494d1a", null ],
    [ "c_plgriddata", "plplot_8d.html#afea251801e6af259cc82f23648e306ef", null ],
    [ "c_plgspa", "plplot_8d.html#a4ce1c92abf1b0e8b03bb121d85a368c4", null ],
    [ "c_plgstrm", "plplot_8d.html#afe7d7e80d20e74398048a49f90fe8543", null ],
    [ "c_plgver", "plplot_8d.html#a4652222050781b78b00731923c12b25d", null ],
    [ "c_plgvpd", "plplot_8d.html#a3533dd7926004f2257aef64b0b4782f9", null ],
    [ "c_plgvpw", "plplot_8d.html#aa790b07d902f8c09be09cba6b9c9e0ac", null ],
    [ "c_plgxax", "plplot_8d.html#ae2629ef40e532bd9856e5a63c8974b1d", null ],
    [ "c_plgyax", "plplot_8d.html#a814bbaa498ccc04e9cf97a7cac4d86ef", null ],
    [ "c_plgzax", "plplot_8d.html#a0d09d91220c22c8d90eb8a4c94a2117f", null ],
    [ "c_plhist", "plplot_8d.html#aed4d8d7bc69de498a92b4c8f305e1ecc", null ],
    [ "c_plhls", "plplot_8d.html#ae64e0e1a256915d94bf330a6427cedce", null ],
    [ "c_plhlsrgb", "plplot_8d.html#a9da5d6fa041c7256061955d7ace6e62a", null ],
    [ "c_plimage", "plplot_8d.html#a6ca701d920c0c0708ad8685969baab6e", null ],
    [ "c_plimagefr", "plplot_8d.html#a4b288976d5756013c9c41dcee6b48bc7", null ],
    [ "c_plinit", "plplot_8d.html#af6879e026a87986cf246b6ad230f5d74", null ],
    [ "c_pljoin", "plplot_8d.html#ac22b591e6252c2aaaa38d4f3bf847375", null ],
    [ "c_pllab", "plplot_8d.html#a49e321eebc6a6d803fc9b2e39bb783ec", null ],
    [ "c_pllegend", "plplot_8d.html#aec97625786c16fb8de98d167bc88f44d", null ],
    [ "c_pllightsource", "plplot_8d.html#a0ec91180b328295174279b595bff19d6", null ],
    [ "c_plline", "plplot_8d.html#a64787a31239b0f65de85ba8f86cc090b", null ],
    [ "c_plline3", "plplot_8d.html#ab692a525dff33d0983d85e80d156c27c", null ],
    [ "c_pllsty", "plplot_8d.html#a618ea88b197ff40d2f4010eaeb9f0f1f", null ],
    [ "c_plmap", "plplot_8d.html#abbed1f0ce5c63859cd965fb705f3b76b", null ],
    [ "c_plmapfill", "plplot_8d.html#a6e8894d848e822253ae7c7be0288822d", null ],
    [ "c_plmapline", "plplot_8d.html#a45dfd021cee74defcf179d3e2afb1279", null ],
    [ "c_plmapstring", "plplot_8d.html#a042a114f197ac7850ea6ddc47934609a", null ],
    [ "c_plmaptex", "plplot_8d.html#a92bddec507cdd2028fee7b29a2637370", null ],
    [ "c_plmeridians", "plplot_8d.html#a5a770471e77b39477f7c99630c37bd42", null ],
    [ "c_plmesh", "plplot_8d.html#adaf1e9a7519889676ffcced8e5f2931f", null ],
    [ "c_plmeshc", "plplot_8d.html#aed89e08e72504dc67d86e6c73e2c9b62", null ],
    [ "c_plmkstrm", "plplot_8d.html#a163a6136396556c52433d6bd1b4342b4", null ],
    [ "c_plmtex", "plplot_8d.html#a57d79fb892b317251c8b6ebd2bc8597a", null ],
    [ "c_plmtex3", "plplot_8d.html#a350b571ed046d914f4aec67415c4d327", null ],
    [ "c_plot3d", "plplot_8d.html#aad2e06707141b1d9eda82255244be437", null ],
    [ "c_plot3dc", "plplot_8d.html#a97b4e3d3837b221abb3878e0cad92571", null ],
    [ "c_plot3dcl", "plplot_8d.html#a7a63f67ccc20ada8f58f50341a2defc0", null ],
    [ "c_plparseopts", "plplot_8d.html#ace9f4712121afe18f49e03247a9d0bf8", null ],
    [ "c_plpat", "plplot_8d.html#a9f21e20dcd28b7e62db6fd0cfd25af9e", null ],
    [ "c_plpath", "plplot_8d.html#ac4fdd88171ca15b54ead1190bccf2a00", null ],
    [ "c_plpoin", "plplot_8d.html#a2b7fa6eb088dd812eff928823407bbc9", null ],
    [ "c_plpoin3", "plplot_8d.html#ae4ff19fae5afde8b74b79f99f6bd64a2", null ],
    [ "c_plpoly3", "plplot_8d.html#a1855a16f99ef4c6fc3f9b3c621aadc4c", null ],
    [ "c_plprec", "plplot_8d.html#aa3907f7f574663e3ec37dd3b907485df", null ],
    [ "c_plpsty", "plplot_8d.html#a4522f80a77dfd548aa7bed716856b499", null ],
    [ "c_plptex", "plplot_8d.html#a67036f2a4a27b50049b422e855c4f0c9", null ],
    [ "c_plptex3", "plplot_8d.html#aaee7e14d276eecfd916f55a794bf3a69", null ],
    [ "c_plrandd", "plplot_8d.html#ab4820fff80380f7c289317fcf2ed5ca7", null ],
    [ "c_plreplot", "plplot_8d.html#a07d9711dc10fbf9ea7fdffb1e9d91147", null ],
    [ "c_plrgb", "plplot_8d.html#a767be979249448d1eab2543023889bbe", null ],
    [ "c_plrgb1", "plplot_8d.html#a738cf078078f3ca046d0f182ccb525df", null ],
    [ "c_plrgbhls", "plplot_8d.html#aa58560f9b13e65f1af751a4d475ceff6", null ],
    [ "c_plschr", "plplot_8d.html#a19594fe2d3a02328e079d1d129345d9c", null ],
    [ "c_plscmap0", "plplot_8d.html#ae07e5a19342e485fb7f53ce444f87573", null ],
    [ "c_plscmap0a", "plplot_8d.html#af71fb1f9196678d1d6d740c1a3847ef2", null ],
    [ "c_plscmap0n", "plplot_8d.html#a0920fb5604acf977bc9aca69c47be7ed", null ],
    [ "c_plscmap1", "plplot_8d.html#accada37b9309ddf254eb1afa524a9070", null ],
    [ "c_plscmap1_range", "plplot_8d.html#a29a94bda1aaa9b38ac3fca311f52595f", null ],
    [ "c_plscmap1a", "plplot_8d.html#a7d71c87565307799e5625c8235dbc78c", null ],
    [ "c_plscmap1l", "plplot_8d.html#aecb1a2c6baba9b2d9263f7b18e72ce17", null ],
    [ "c_plscmap1la", "plplot_8d.html#a24e9d59d944076ab6279b99ec08a2995", null ],
    [ "c_plscmap1n", "plplot_8d.html#a66f0b61d364949eab1a056889177319a", null ],
    [ "c_plscol0", "plplot_8d.html#ac2efd50cd2f897656cf71eca362101c0", null ],
    [ "c_plscol0a", "plplot_8d.html#a42479faafba4397a48eb085714c715a8", null ],
    [ "c_plscolbg", "plplot_8d.html#afd764b91fa91ae8da66d570c8f4d37a7", null ],
    [ "c_plscolbga", "plplot_8d.html#a559bb58fa3e6d4ba21016c6f4d117710", null ],
    [ "c_plscolor", "plplot_8d.html#a920136608e27e71bfa5e29878c87108f", null ],
    [ "c_plscompression", "plplot_8d.html#a6b65c95b8ff73c712de40b1c363c50e3", null ],
    [ "c_plsdev", "plplot_8d.html#a3409c29d4fc6b6a42ff0578989f75b5c", null ],
    [ "c_plsdidev", "plplot_8d.html#acd3fb7e953c04436d72775c3750f8cdb", null ],
    [ "c_plsdimap", "plplot_8d.html#ab390c7e23a409ebc83487fb24bd3f4a1", null ],
    [ "c_plsdiori", "plplot_8d.html#ab73c9c095f74ca273e0fc2e6beb6e701", null ],
    [ "c_plsdiplt", "plplot_8d.html#a1b320e3438c997ca5ed63daa146b22cc", null ],
    [ "c_plsdiplz", "plplot_8d.html#ae9319937d871369ef1ac7bfa6db6f9c6", null ],
    [ "c_plseed", "plplot_8d.html#ade77713fe63f4f3c796847918625aa7c", null ],
    [ "c_plsesc", "plplot_8d.html#ab9c2c7637fcaf5115c364307ccc09c9a", null ],
    [ "c_plsetopt", "plplot_8d.html#a45bc5770619fe161595a2df6b7072fae", null ],
    [ "c_plsfam", "plplot_8d.html#ae6df129abea7da20822ab2f8e4d04c95", null ],
    [ "c_plsfci", "plplot_8d.html#a8c335543dfd6a3f04afd9e22e412bb57", null ],
    [ "c_plsfnam", "plplot_8d.html#abf9a388c1ceb8a0d0c3c5c4e1038dcdf", null ],
    [ "c_plsfont", "plplot_8d.html#a5b068eafc7f0e005e57efdf2345bdd75", null ],
    [ "c_plshade", "plplot_8d.html#aff655c6b4bfe486a4826d684f7eb8162", null ],
    [ "c_plshades", "plplot_8d.html#a965abbc050863a7fb8be7f8b9c95ba8c", null ],
    [ "c_plslabelfunc", "plplot_8d.html#a3afe1f3514bd9954f8298df421bff580", null ],
    [ "c_plsmaj", "plplot_8d.html#aece3d659a68624da7636e7fa347c340e", null ],
    [ "c_plsmem", "plplot_8d.html#a8dbab3b79283c14dcd32b500b512fc1e", null ],
    [ "c_plsmin", "plplot_8d.html#afb634e82ed33c8f87328c9b78521c549", null ],
    [ "c_plsori", "plplot_8d.html#ac6700874a4b5d3e55a04206ccafa22bc", null ],
    [ "c_plspage", "plplot_8d.html#a5faaf381f93b54562b9770d83362b5c8", null ],
    [ "c_plspal0", "plplot_8d.html#af005a6a8034510f226b39e43caf7860a", null ],
    [ "c_plspal1", "plplot_8d.html#a60bec4b2a44cfe04f6e23060a4d50d1c", null ],
    [ "c_plspause", "plplot_8d.html#aad4df2664d5f6ae82dff7c55544e4e43", null ],
    [ "c_plsstrm", "plplot_8d.html#ae21f336a8237340b039a0ca3c849b949", null ],
    [ "c_plssub", "plplot_8d.html#adfc9ae0867311b43cde87d6c733bd479", null ],
    [ "c_plssym", "plplot_8d.html#ae6219d749ee7630013cc5e6f91a64af9", null ],
    [ "c_plstar", "plplot_8d.html#a80ca439ae6fe5db885c066ec461efa62", null ],
    [ "c_plstart", "plplot_8d.html#a23d9f44ae538a81b5989f284583e0cf6", null ],
    [ "c_plstransform", "plplot_8d.html#a247e7fabb00a5f2ac6d81385d366709b", null ],
    [ "c_plstring", "plplot_8d.html#a31a1d0908fcb030d73f2454fd5315114", null ],
    [ "c_plstring3", "plplot_8d.html#a69b4ec3b9328c306109dad867b0c6dab", null ],
    [ "c_plstripa", "plplot_8d.html#a108b680da31e4c7a095f3473b60786ee", null ],
    [ "c_plstripc", "plplot_8d.html#a32aa2b808e423b153f9f3eb030b3c51f", null ],
    [ "c_plstripd", "plplot_8d.html#a84b3127d90d825393c1fbb0316a30644", null ],
    [ "c_plstyl", "plplot_8d.html#a924d8f64da03bc1a5e4e0e0967d93d79", null ],
    [ "c_plsurf3d", "plplot_8d.html#ac18743efda3f9dff0dc24c6dc292ba77", null ],
    [ "c_plsurf3dl", "plplot_8d.html#ad35774ef7ff45374a25f3900fba734eb", null ],
    [ "c_plsvect", "plplot_8d.html#a72613f978d226b4a897c4d7269c56dd1", null ],
    [ "c_plsvpa", "plplot_8d.html#a2b15e0d17c27ac69d0501c23a2818848", null ],
    [ "c_plsxax", "plplot_8d.html#afacd806428c2be8dd8f86ae3fe5d7a84", null ],
    [ "c_plsyax", "plplot_8d.html#a84a37999ae9afa6db889d6e77e058e2a", null ],
    [ "c_plsym", "plplot_8d.html#ae83b3ce6296a1932455a976c8262b0a6", null ],
    [ "c_plszax", "plplot_8d.html#a7cd456b38d1a02f958df83d81c15eeea", null ],
    [ "c_pltext", "plplot_8d.html#a426135b864521001f1048223f4d97bf1", null ],
    [ "c_pltimefmt", "plplot_8d.html#aae6cd0577e41bed837f0df5766dd203e", null ],
    [ "c_plvasp", "plplot_8d.html#af28bc6aa01b3bda2fb22dd2988beb6e9", null ],
    [ "c_plvect", "plplot_8d.html#abfe95f7e5cee37e1b7c449c1bde17854", null ],
    [ "c_plvpas", "plplot_8d.html#a9db90eb66c2c80dd6f4d40c60d361a53", null ],
    [ "c_plvpor", "plplot_8d.html#aafb44a4d4a54f5a5dd45c089b69a76e2", null ],
    [ "c_plvsta", "plplot_8d.html#adf0f30dfd998a1253eab87d34fae0586", null ],
    [ "c_plw3d", "plplot_8d.html#aa418c196c1f05952dbebfef67071846d", null ],
    [ "c_plwidth", "plplot_8d.html#ac139793483186b792df01ce773ffe2be", null ],
    [ "c_plwind", "plplot_8d.html#ab9aa6fab9ceb4a738f32415851035a7d", null ],
    [ "c_plxormod", "plplot_8d.html#a4b47230cae3dd41861550e900b35b8c6", null ],
    [ "convert_array", "plplot_8d.html#aba0627d998c5a1e8fe7e417bbb69ce7b", null ],
    [ "function", "plplot_8d.html#aceb3b1f1bdf6db2420a9ede4c2566964", null ],
    [ "function", "plplot_8d.html#a37daf0964156f868b9157a1f1d5b8a8c", null ],
    [ "function", "plplot_8d.html#a760725e8504fd8ac4457541ccd9d53bc", null ],
    [ "pl_cmd", "plplot_8d.html#a50aa4e4628b4750768d742ecd5e4761c", null ],
    [ "plAlloc2dGrid", "plplot_8d.html#a7e2323913de7032fb778f2ee7a96ec05", null ],
    [ "plaxes", "plplot_8d.html#a3cc385b5f47e76d56a9b4844a38880dc", null ],
    [ "plbin", "plplot_8d.html#a9ba5d3d4257d6a8bf175427d9f87a22c", null ],
    [ "plbox", "plplot_8d.html#a657c353f7d1d61973a5177afe84054ae", null ],
    [ "plbox3", "plplot_8d.html#a91bd0a7c66a07ec3ee391469e16bcfbc", null ],
    [ "plClearOpts", "plplot_8d.html#a22d99da0dba5493c61b4777d3108431d", null ],
    [ "plcolorbar", "plplot_8d.html#a39c63e87cf56201340c259b98755a904", null ],
    [ "plcont", "plplot_8d.html#ad9b767854ac3986366fd780ba06530be", null ],
    [ "plcont", "plplot_8d.html#aa2a34d9546359bbad34fc6c22426ca11", null ],
    [ "plcont", "plplot_8d.html#acb27c146395d3d5233998eccd0a2d516", null ],
    [ "pldid2pc", "plplot_8d.html#ada2c3c3ba118795e67544f8fa1e38fcd", null ],
    [ "pldip2dc", "plplot_8d.html#adb5aa5f1dbd8d65cbdb8c9e99f637a02", null ],
    [ "plerrx", "plplot_8d.html#a8a45faade0c573046cb01a115d174a27", null ],
    [ "plerry", "plplot_8d.html#a6449e069d7de350897c12acdba79a1dc", null ],
    [ "plf2eval", "plplot_8d.html#aaa2f9c69c2f220a6831eee510374b528", null ],
    [ "plf2eval2", "plplot_8d.html#a1b77361a9dae31b8185b0c9a818fbf9d", null ],
    [ "plf2evalr", "plplot_8d.html#a3a8e6fa16be9e065e9357c8876d96fe3", null ],
    [ "plfcont", "plplot_8d.html#a418dd819c7b144eb83fbfb0494b33542", null ],
    [ "plfill", "plplot_8d.html#a9fdb9570c1ed9435e75e927fab0cbf87", null ],
    [ "plfill3", "plplot_8d.html#a645488cd243969410cbd44bc0cab1589", null ],
    [ "plFindCommand", "plplot_8d.html#a94bc85629dffbcbbb917f009a0ee3af9", null ],
    [ "plFindName", "plplot_8d.html#abbce2b958f59f10ca1005aa114b8b309", null ],
    [ "plFree2dGrid", "plplot_8d.html#a15ce3678e2836637e50e5e66479a3de8", null ],
    [ "plfshade", "plplot_8d.html#a06d5695e241716c53743148c19b5d6e5", null ],
    [ "plgdev", "plplot_8d.html#ac5f3acaa2aa266c937dd8b31b3c5c422", null ],
    [ "plgDevs", "plplot_8d.html#a38f7971a30ce87be17d7d9eab878ec88", null ],
    [ "plgesc", "plplot_8d.html#a0a523a5b622c0f35d22d67f5564fbbc1", null ],
    [ "plGetCursor", "plplot_8d.html#a3a2e2101b007a7112189651c3f11e93f", null ],
    [ "plGetFlt", "plplot_8d.html#ae73b7e038382b52be7d53ebd9cc9af28", null ],
    [ "plGetInt", "plplot_8d.html#a3ead8986ee01833ff72e5bf83a2f41b9", null ],
    [ "plGetName", "plplot_8d.html#a21b47fd689d4c3533b418240687bb64e", null ],
    [ "plgFileDevs", "plplot_8d.html#a2ce3c2363f59300f16c7fc50abce3482", null ],
    [ "plgfnam", "plplot_8d.html#a61a66c3405c4a9c31efdb53b3b2072c4", null ],
    [ "plgradient", "plplot_8d.html#a8f5be14e14902cdff2467ed40c03d604", null ],
    [ "plgriddata", "plplot_8d.html#abd565c5013fb2287c4ff30de537502b2", null ],
    [ "plgver", "plplot_8d.html#a9682017a6d1473433581103bb2a65791", null ],
    [ "plhist", "plplot_8d.html#ac1cf5eaeed8d5276c41c0befc2ca02f7", null ],
    [ "plimage", "plplot_8d.html#a1d049b39333cb7795adc5d87c093b185", null ],
    [ "plimagefr", "plplot_8d.html#a6b1721b282bf4d8090b7af3942c69513", null ],
    [ "plimagefr", "plplot_8d.html#a2ac6f96bfca5812d1848884fcf797925", null ],
    [ "plimagefr", "plplot_8d.html#a341d362ecb20e456b68ac346e426947c", null ],
    [ "pllab", "plplot_8d.html#a725472b7ec641a3a397e7e3e010a71dd", null ],
    [ "pllegend", "plplot_8d.html#a82f003c7ac4b4781c5aceb3b9a64af26", null ],
    [ "plline", "plplot_8d.html#ad5d3f049bd8961288ecf91205bc4976a", null ],
    [ "plline3", "plplot_8d.html#ad4604a276fb5c54f48a649567854a0db", null ],
    [ "plmap", "plplot_8d.html#a9927f928134f967d9830abc78d361199", null ],
    [ "plmapfill", "plplot_8d.html#a890ea5d3b655546c41fa3ec8371b2310", null ],
    [ "plmapline", "plplot_8d.html#a547b81f3ad2285393e73fcee988f3e40", null ],
    [ "plmapstring", "plplot_8d.html#aec5de0c3c5663b6c7797ea1d28920e51", null ],
    [ "plmaptex", "plplot_8d.html#a223f1ec44e835b3ce49f1d19354cf91c", null ],
    [ "plMergeOpts", "plplot_8d.html#ae5dbeb44b28005ff66ef0bb7a9191351", null ],
    [ "plmesh", "plplot_8d.html#a6abc40bbf2db54f712e7dea351754b39", null ],
    [ "plmeshc", "plplot_8d.html#a4a98e97ec18151452a4227290d3caecb", null ],
    [ "plMinMax2dGrid", "plplot_8d.html#aa901605aec60895f98772081324bbfca", null ],
    [ "plMinMax2dGrid", "plplot_8d.html#a514abf5d142bb684b77139fc482c214c", null ],
    [ "plmtex", "plplot_8d.html#acec852e8868053578526ae9582f1eae7", null ],
    [ "plmtex3", "plplot_8d.html#a7c3ad5347a3fc308dbf36989cf2e8ea4", null ],
    [ "plOptUsage", "plplot_8d.html#ad81d5d39ef7364e99e6a45a9801c2618", null ],
    [ "plot3d", "plplot_8d.html#a187fb271627ffdd6c23cc25a8a190ac3", null ],
    [ "plot3dc", "plplot_8d.html#afe95f89dafd679d2062e0e4397d8f164", null ],
    [ "plot3dcl", "plplot_8d.html#a35573ef59c67c106c058b1b0a774512f", null ],
    [ "plparseopts", "plplot_8d.html#a7a0ec47b66212facd52955ca6cd3220a", null ],
    [ "plpat", "plplot_8d.html#a618d1d9e800297e70d0855f877246541", null ],
    [ "plpoin", "plplot_8d.html#a5f173da2f4add42e753709240c669705", null ],
    [ "plpoin3", "plplot_8d.html#a6737787ee2fe7d6d344315d8992ecf98", null ],
    [ "plpoly3", "plplot_8d.html#a15cb816027e79e07d66d4d6660df4c4b", null ],
    [ "plptex", "plplot_8d.html#a8c937c6872d56a36fbc81bf374bddee0", null ],
    [ "plptex3", "plplot_8d.html#a9b32f35a6398eac1bc3614771e93b072", null ],
    [ "plResetOpts", "plplot_8d.html#a034ba7bac4e8ed886747abd4397be838", null ],
    [ "plsabort", "plplot_8d.html#a57513702aadde373e696490e1f5df570", null ],
    [ "plsbopH", "plplot_8d.html#aca11a4d7441696d6a6cef3a6f73dbbb2", null ],
    [ "plsButtonEH", "plplot_8d.html#a88187103846a7f977f0453e8dfef7560", null ],
    [ "plscmap0", "plplot_8d.html#a2908d57cff1ad5dade6397af47138777", null ],
    [ "plscmap0a", "plplot_8d.html#a5723801f2e4e8487658b7cff7102a0fe", null ],
    [ "plscmap1", "plplot_8d.html#a92669c23526d49df62416cf942208a92", null ],
    [ "plscmap1a", "plplot_8d.html#a71e74e486f203786d924f64f8ba20df4", null ],
    [ "plscmap1l", "plplot_8d.html#a0d57569295ec0852f57d72c33d9c6c5f", null ],
    [ "plscmap1la", "plplot_8d.html#a414fc194efc731cddad6d831228c8933", null ],
    [ "plsdev", "plplot_8d.html#afecb611a015a94a6934e7f9d8a8b9e61", null ],
    [ "plseopH", "plplot_8d.html#af141bfd63c48d0ec1d5429cfa24e211d", null ],
    [ "plsError", "plplot_8d.html#a5248d20a8e70740bf885d16f65b5103f", null ],
    [ "plsetopt", "plplot_8d.html#aa3d188c7f73a093b0d3eb6616eccc209", null ],
    [ "plSetUsage", "plplot_8d.html#aad8dfba8a001aec5a019f149280ac971", null ],
    [ "plsexit", "plplot_8d.html#a3ee8d5347a570039722892589c8f063a", null ],
    [ "plsfnam", "plplot_8d.html#ae12690df17e92a922f3e760915205344", null ],
    [ "plshade", "plplot_8d.html#ad9b06fdfd37609a795bb6f46bef1da9f", null ],
    [ "plshades", "plplot_8d.html#a8fc78fdca040a7f85f2dd32877b425a8", null ],
    [ "plshades", "plplot_8d.html#a13769068005b0cc3e3015b52062fd41c", null ],
    [ "plshades", "plplot_8d.html#aa3269f3afdfce761378113975556a184", null ],
    [ "plsKeyEH", "plplot_8d.html#addfb7dc1426573968a00604eeaa2b974", null ],
    [ "plspal0", "plplot_8d.html#a73bf2f7716abced91417e22fcb2cc623", null ],
    [ "plspal1", "plplot_8d.html#a9ab9448cee98796b53d6347861ee3845", null ],
    [ "plstart", "plplot_8d.html#a9b2d220b3a1d7e9c704850d9e863dedd", null ],
    [ "plstring", "plplot_8d.html#a8bf6e0c9d370c839332c462301971c4d", null ],
    [ "plstring3", "plplot_8d.html#a525d76a0979c6182ea6112f245001d68", null ],
    [ "plstripc", "plplot_8d.html#a6a4c993ac02b4bf506c20151accd9e0e", null ],
    [ "plstyl", "plplot_8d.html#a2a6d65908b1245b162a203130d22d3a5", null ],
    [ "plsurf3d", "plplot_8d.html#a4a2a4509784da702b641e7d4ebfb4930", null ],
    [ "plsurf3dl", "plplot_8d.html#a321cdc50ac5762ff9a97d5c42f8514ab", null ],
    [ "plsvect", "plplot_8d.html#a7edf855e0491d206e8d53235b7ed9cbe", null ],
    [ "plsxwin", "plplot_8d.html#ac79a04061e786bfc88f0db73242e3c7e", null ],
    [ "plsym", "plplot_8d.html#af27ec113c5def557035ffcb1ecd4494c", null ],
    [ "pltimefmt", "plplot_8d.html#af38adb2ca4c4336990909ac4a30ec164", null ],
    [ "pltr0", "plplot_8d.html#aff4f9c6db8581a188b7b36f41b570965", null ],
    [ "pltr0f", "plplot_8d.html#a60ddaf301613b2a321a2c4a18d8c01f3", null ],
    [ "pltr1", "plplot_8d.html#a1480d8b0b53c881f2e26f8c4d5e23aa7", null ],
    [ "pltr2", "plplot_8d.html#a1bd5743f31ac7964d45af29a8424d67e", null ],
    [ "pltr2f", "plplot_8d.html#aceb0f975de3fe0c0542d41c5857c73b6", null ],
    [ "pltr2p", "plplot_8d.html#a4ef6478fcbade835aaa044d85bd8d9fa", null ],
    [ "plTranslateCursor", "plplot_8d.html#aac27ed21119b687f22ff91f6cf9935c9", null ],
    [ "plvect", "plplot_8d.html#a09d7a432094053dac57e58317028f632", null ],
    [ "plvect", "plplot_8d.html#a0545bf79b1de4f9937ef82312cc0036f", null ],
    [ "plvect", "plplot_8d.html#a1c5652bf73ca79ee688220064c81cea2", null ]
];